Flask-actions provide some management comands for flask based project.

.. contents::

Links
===============================

* `documentation <http://packages.python.org/Flask-Actions>`_
* `development version
  <http://bitbucket.org/youngking/flask-actions/get/tip.gz#egg=Flask-Actions-dev>`_
